evolution/evolution-GtkHVBox.patch

465 lines
15 KiB
Diff
Raw Blame History

This file contains invisible Unicode characters

This file contains invisible Unicode characters that are indistinguishable to humans but may be processed differently by a computer. If you think that this is intentional, you can safely ignore this warning. Use the Escape button to reveal them.

From b53cc892a7fd0048f0bee85faf673df7b226ad9e Mon Sep 17 00:00:00 2001
From: Dominique Leuenberger <dimstar@opensuse.org>
Date: Mon, 8 Aug 2011 09:48:37 +0200
Subject: [PATCH] bgo#656143: Stop using deprecated Gtk[HV]Box(Class)?
---
calendar/gui/e-timezone-entry.h | 4 ++--
capplet/settings/mail-account-view.h | 4 ++--
capplet/settings/mail-settings-view.h | 4 ++--
capplet/settings/mail-view.h | 2 +-
e-util/e-config.c | 4 ++--
e-util/e-config.h | 4 ++--
mail/e-mail-attachment-bar.h | 4 ++--
mail/e-mail-pane.h | 4 ++--
mail/e-mail-view.h | 4 ++--
modules/calendar/e-calendar-preferences.h | 4 ++--
modules/mail/em-composer-prefs.h | 4 ++--
modules/mail/em-mailer-prefs.h | 4 ++--
modules/mail/em-network-prefs.h | 4 ++--
plugins/itip-formatter/itip-view.h | 4 ++--
shell/e-shell-taskbar.h | 4 ++--
widgets/misc/e-alert-bar.c | 2 +-
widgets/misc/e-attachment-button.h | 4 ++--
widgets/misc/e-dateedit.h | 4 ++--
widgets/misc/e-image-chooser.h | 4 ++--
widgets/misc/e-preview-pane.h | 4 ++--
widgets/misc/e-search-bar.h | 4 ++--
widgets/misc/e-url-entry.h | 4 ++--
widgets/table/e-table-field-chooser.h | 4 ++--
23 files changed, 44 insertions(+), 44 deletions(-)
Index: evolution-3.1.4/calendar/gui/e-timezone-entry.h
===================================================================
--- evolution-3.1.4.orig/calendar/gui/e-timezone-entry.h
+++ evolution-3.1.4/calendar/gui/e-timezone-entry.h
@@ -61,12 +61,12 @@ typedef struct _ETimezoneEntryClass ETim
typedef struct _ETimezoneEntryPrivate ETimezoneEntryPrivate;
struct _ETimezoneEntry {
- GtkHBox parent;
+ GtkBox parent;
ETimezoneEntryPrivate *priv;
};
struct _ETimezoneEntryClass {
- GtkHBoxClass parent_class;
+ GtkBoxClass parent_class;
void (*changed) (ETimezoneEntry *timezone_entry);
};
Index: evolution-3.1.4/capplet/settings/mail-account-view.h
===================================================================
--- evolution-3.1.4.orig/capplet/settings/mail-account-view.h
+++ evolution-3.1.4/capplet/settings/mail-account-view.h
@@ -60,7 +60,7 @@ typedef struct _MAVPage {
}MAVPage;
typedef struct _MailAccountView {
- GtkVBox parent;
+ GtkBox parent;
gint type;
const gchar *uri;
MailViewFlags flags;
@@ -80,7 +80,7 @@ typedef struct _MailAccountView {
} MailAccountView;
typedef struct _MailAccountViewClass {
- GtkVBoxClass parent_class;
+ GtkBoxClass parent_class;
void (* view_close) (MailAccountView *);
Index: evolution-3.1.4/capplet/settings/mail-settings-view.h
===================================================================
--- evolution-3.1.4.orig/capplet/settings/mail-settings-view.h
+++ evolution-3.1.4/capplet/settings/mail-settings-view.h
@@ -36,7 +36,7 @@
typedef struct _MailSettingsViewPrivate MailSettingsViewPrivate;
typedef struct _MailSettingsView {
- GtkVBox parent;
+ GtkBox parent;
gint type;
const gchar *uri;
MailViewFlags flags;
@@ -46,7 +46,7 @@ typedef struct _MailSettingsView {
} MailSettingsView;
typedef struct _MailSettingsViewClass {
- GtkVBoxClass parent_class;
+ GtkBoxClass parent_class;
void (* view_close) (MailSettingsView *);
void (* show_account) (MailSettingsView *, gpointer);
Index: evolution-3.1.4/capplet/settings/mail-view.h
===================================================================
--- evolution-3.1.4.orig/capplet/settings/mail-view.h
+++ evolution-3.1.4/capplet/settings/mail-view.h
@@ -69,7 +69,7 @@ typedef enum {
} MailViewFlags;
typedef struct _MailViewChild {
- GtkVBox parent;
+ GtkBox parent;
gint type;
gchar *uri;
MailViewFlags flags;
Index: evolution-3.1.4/e-util/e-config.h
===================================================================
--- evolution-3.1.4.orig/e-util/e-config.h
+++ evolution-3.1.4/e-util/e-config.h
@@ -122,9 +122,9 @@ enum _e_config_target_change_t {
* @E_CONFIG_SECTION: A section in the configuration page. A page for
* this section must have already been defined. The item @label if
* supplied will be setup as a borderless hig-compliant frame title.
- * The content of the section will be a GtkVBox. If a factory is used
+ * The content of the section will be a GtkBox. If a factory is used
* then it is up to the factory method to create the section and add
- * it to the parent page, and return a GtkVBox for following sections.
+ * it to the parent page, and return a GtkBox for following sections.
* @E_CONFIG_SECTION_TABLE: A table section. The same as an
* @E_CONFIG_SECTION but the content object is a GtkTable instead.
* @E_CONFIG_ITEM: A configuration item. It must have a parent
Index: evolution-3.1.4/mail/e-mail-attachment-bar.h
===================================================================
--- evolution-3.1.4.orig/mail/e-mail-attachment-bar.h
+++ evolution-3.1.4/mail/e-mail-attachment-bar.h
@@ -51,12 +51,12 @@ typedef struct _EMailAttachmentBarClass
typedef struct _EMailAttachmentBarPrivate EMailAttachmentBarPrivate;
struct _EMailAttachmentBar {
- GtkVBox parent;
+ GtkBox parent;
EMailAttachmentBarPrivate *priv;
};
struct _EMailAttachmentBarClass {
- GtkVBoxClass parent_class;
+ GtkBoxClass parent_class;
};
GType e_mail_attachment_bar_get_type (void);
Index: evolution-3.1.4/mail/e-mail-view.h
===================================================================
--- evolution-3.1.4.orig/mail/e-mail-view.h
+++ evolution-3.1.4/mail/e-mail-view.h
@@ -53,12 +53,12 @@ typedef struct _EMailViewClass EMailView
typedef struct _EMailViewPrivate EMailViewPrivate;
struct _EMailView {
- GtkVBox parent;
+ GtkBox parent;
EMailViewPrivate *priv;
};
struct _EMailViewClass {
- GtkVBoxClass parent_class;
+ GtkBoxClass parent_class;
/* Signals */
void (*pane_close) (EMailView *view);
Index: evolution-3.1.4/modules/calendar/e-calendar-preferences.h
===================================================================
--- evolution-3.1.4.orig/modules/calendar/e-calendar-preferences.h
+++ evolution-3.1.4/modules/calendar/e-calendar-preferences.h
@@ -54,7 +54,7 @@ typedef struct _ECalendarPreferences ECa
typedef struct _ECalendarPreferencesClass ECalendarPreferencesClass;
struct _ECalendarPreferences {
- GtkVBox parent;
+ GtkBox parent;
GtkBuilder *builder;
@@ -76,7 +76,7 @@ struct _ECalendarPreferences {
};
struct _ECalendarPreferencesClass {
- GtkVBoxClass parent;
+ GtkBoxClass parent;
};
GType e_calendar_preferences_get_type (void);
Index: evolution-3.1.4/modules/mail/em-composer-prefs.h
===================================================================
--- evolution-3.1.4.orig/modules/mail/em-composer-prefs.h
+++ evolution-3.1.4/modules/mail/em-composer-prefs.h
@@ -56,7 +56,7 @@ typedef struct _EMComposerPrefsClass EMC
struct _ESignature;
struct _EMComposerPrefs {
- GtkVBox parent;
+ GtkBox parent;
GtkBuilder *builder;
@@ -73,7 +73,7 @@ struct _EMComposerPrefs {
};
struct _EMComposerPrefsClass {
- GtkVBoxClass parent_class;
+ GtkBoxClass parent_class;
};
GType em_composer_prefs_get_type (void);
Index: evolution-3.1.4/modules/mail/em-mailer-prefs.h
===================================================================
--- evolution-3.1.4.orig/modules/mail/em-mailer-prefs.h
+++ evolution-3.1.4/modules/mail/em-mailer-prefs.h
@@ -53,7 +53,7 @@ typedef struct _EMMailerPrefs EMMailerPr
typedef struct _EMMailerPrefsClass EMMailerPrefsClass;
struct _EMMailerPrefs {
- GtkVBox parent_object;
+ GtkBox parent_object;
GtkBuilder *builder;
GConfClient *gconf;
@@ -103,7 +103,7 @@ struct _EMMailerPrefs {
};
struct _EMMailerPrefsClass {
- GtkVBoxClass parent_class;
+ GtkBoxClass parent_class;
};
GType em_mailer_prefs_get_type (void);
Index: evolution-3.1.4/modules/mail/em-network-prefs.h
===================================================================
--- evolution-3.1.4.orig/modules/mail/em-network-prefs.h
+++ evolution-3.1.4/modules/mail/em-network-prefs.h
@@ -59,7 +59,7 @@ typedef enum {
} NetworkConfigProxyType;
struct _EMNetworkPrefs {
- GtkVBox parent_object;
+ GtkBox parent_object;
GConfClient *gconf;
@@ -91,7 +91,7 @@ struct _EMNetworkPrefs {
};
struct _EMNetworkPrefsClass {
- GtkVBoxClass parent_class;
+ GtkBoxClass parent_class;
};
GType em_network_prefs_get_type (void);
Index: evolution-3.1.4/plugins/itip-formatter/itip-view.h
===================================================================
--- evolution-3.1.4.orig/plugins/itip-formatter/itip-view.h
+++ evolution-3.1.4/plugins/itip-formatter/itip-view.h
@@ -76,7 +76,7 @@ typedef enum {
} ItipViewInfoItemType;
struct _ItipView {
- GtkHBox parent_instance;
+ GtkBox parent_instance;
ItipViewPrivate *priv;
@@ -84,7 +84,7 @@ struct _ItipView {
};
struct _ItipViewClass {
- GtkHBoxClass parent_class;
+ GtkBoxClass parent_class;
void (* source_selected) (ItipView *view, ESource *selected_source);
void (* response) (ItipView *view, gint response);
Index: evolution-3.1.4/shell/e-shell-taskbar.h
===================================================================
--- evolution-3.1.4.orig/shell/e-shell-taskbar.h
+++ evolution-3.1.4/shell/e-shell-taskbar.h
@@ -59,12 +59,12 @@ typedef struct _EShellTaskbarPrivate ESh
* functions below.
**/
struct _EShellTaskbar {
- GtkHBox parent;
+ GtkBox parent;
EShellTaskbarPrivate *priv;
};
struct _EShellTaskbarClass {
- GtkHBoxClass parent_class;
+ GtkBoxClass parent_class;
};
GType e_shell_taskbar_get_type (void);
Index: evolution-3.1.4/widgets/misc/e-alert-bar.c
===================================================================
--- evolution-3.1.4.orig/widgets/misc/e-alert-bar.c
+++ evolution-3.1.4/widgets/misc/e-alert-bar.c
@@ -177,7 +177,7 @@ alert_bar_dispose (GObject *object)
static GtkSizeRequestMode
alert_bar_get_request_mode (GtkWidget *widget)
{
- /* GtkHBox does width-for-height by default. But we
+ /* GtkBox does width-for-height by default. But we
* want the alert bar to be as short as possible. */
return GTK_SIZE_REQUEST_HEIGHT_FOR_WIDTH;
}
Index: evolution-3.1.4/widgets/misc/e-attachment-button.h
===================================================================
--- evolution-3.1.4.orig/widgets/misc/e-attachment-button.h
+++ evolution-3.1.4/widgets/misc/e-attachment-button.h
@@ -52,12 +52,12 @@ typedef struct _EAttachmentButtonClass E
typedef struct _EAttachmentButtonPrivate EAttachmentButtonPrivate;
struct _EAttachmentButton {
- GtkHBox parent;
+ GtkBox parent;
EAttachmentButtonPrivate *priv;
};
struct _EAttachmentButtonClass {
- GtkHBoxClass parent_class;
+ GtkBoxClass parent_class;
};
GType e_attachment_button_get_type (void);
Index: evolution-3.1.4/widgets/misc/e-dateedit.h
===================================================================
--- evolution-3.1.4.orig/widgets/misc/e-dateedit.h
+++ evolution-3.1.4/widgets/misc/e-dateedit.h
@@ -60,14 +60,14 @@ typedef struct tm (*EDateEditGetTimeCall
gpointer data);
struct _EDateEdit {
- GtkHBox hbox;
+ GtkBox hbox;
/*< private >*/
EDateEditPrivate *priv;
};
struct _EDateEditClass {
- GtkHBoxClass parent_class;
+ GtkBoxClass parent_class;
void (* changed) (EDateEdit *dedit);
};
Index: evolution-3.1.4/widgets/misc/e-image-chooser.h
===================================================================
--- evolution-3.1.4.orig/widgets/misc/e-image-chooser.h
+++ evolution-3.1.4/widgets/misc/e-image-chooser.h
@@ -50,12 +50,12 @@ typedef struct _EImageChooserClass EImag
typedef struct _EImageChooserPrivate EImageChooserPrivate;
struct _EImageChooser {
- GtkVBox parent;
+ GtkBox parent;
EImageChooserPrivate *priv;
};
struct _EImageChooserClass {
- GtkVBoxClass parent_class;
+ GtkBoxClass parent_class;
/* signals */
void (*changed) (EImageChooser *chooser);
Index: evolution-3.1.4/widgets/misc/e-preview-pane.h
===================================================================
--- evolution-3.1.4.orig/widgets/misc/e-preview-pane.h
+++ evolution-3.1.4/widgets/misc/e-preview-pane.h
@@ -52,12 +52,12 @@ typedef struct _EPreviewPaneClass EPrevi
typedef struct _EPreviewPanePrivate EPreviewPanePrivate;
struct _EPreviewPane {
- GtkVBox parent;
+ GtkBox parent;
EPreviewPanePrivate *priv;
};
struct _EPreviewPaneClass {
- GtkVBoxClass parent_class;
+ GtkBoxClass parent_class;
/* Signals */
void (*show_search_bar) (EPreviewPane *preview_pane);
Index: evolution-3.1.4/widgets/misc/e-search-bar.h
===================================================================
--- evolution-3.1.4.orig/widgets/misc/e-search-bar.h
+++ evolution-3.1.4/widgets/misc/e-search-bar.h
@@ -52,12 +52,12 @@ typedef struct _ESearchBarClass ESearchB
typedef struct _ESearchBarPrivate ESearchBarPrivate;
struct _ESearchBar {
- GtkHBox parent;
+ GtkBox parent;
ESearchBarPrivate *priv;
};
struct _ESearchBarClass {
- GtkHBoxClass parent_class;
+ GtkBoxClass parent_class;
/* Signals */
void (*changed) (ESearchBar *search_bar);
Index: evolution-3.1.4/widgets/misc/e-url-entry.h
===================================================================
--- evolution-3.1.4.orig/widgets/misc/e-url-entry.h
+++ evolution-3.1.4/widgets/misc/e-url-entry.h
@@ -39,13 +39,13 @@ typedef struct _EUrlEntryPrivate EUrlEnt
typedef struct _EUrlEntryClass EUrlEntryClass;
struct _EUrlEntry {
- GtkHBox parent;
+ GtkBox parent;
EUrlEntryPrivate *priv;
};
struct _EUrlEntryClass {
- GtkHBoxClass parent_class;
+ GtkBoxClass parent_class;
};
Index: evolution-3.1.4/widgets/table/e-table-field-chooser.h
===================================================================
--- evolution-3.1.4.orig/widgets/table/e-table-field-chooser.h
+++ evolution-3.1.4/widgets/table/e-table-field-chooser.h
@@ -53,7 +53,7 @@ typedef struct _ETableFieldChooser ETabl
typedef struct _ETableFieldChooserClass ETableFieldChooserClass;
struct _ETableFieldChooser {
- GtkVBox parent;
+ GtkBox parent;
/* item specific fields */
GnomeCanvas *canvas;
@@ -68,7 +68,7 @@ struct _ETableFieldChooser {
};
struct _ETableFieldChooserClass {
- GtkVBoxClass parent_class;
+ GtkBoxClass parent_class;
};
GType e_table_field_chooser_get_type (void) G_GNUC_CONST;
Index: evolution-3.1.4/e-util/e-config.c
===================================================================
--- evolution-3.1.4.orig/e-util/e-config.c
+++ evolution-3.1.4/e-util/e-config.c
@@ -940,7 +940,7 @@ ec_rebuild (EConfig *emp)
/* ITEMs are called with the section parent.
The type depends on the section type,
- either a GtkTable, or a GtkVBox */
+ either a GtkTable, or a GtkBox */
w = NULL;
if (section == NULL) {
wn->widget = NULL;
@@ -1347,7 +1347,7 @@ e_config_page_check (EConfig *config, co
* Retrieve the page widget corresponding to @pageid.
*
* Return value: The page widget. It will be the root GtkNotebook
* container or the GtkVBox object inside the assistant.
**/
GtkWidget *
e_config_page_get (EConfig *ec, const gchar *pageid)
@@ -1347,7 +1347,7 @@ e_config_page_check (EConfig *config, co
*
* Return value: The page widget. It will be the root GtkNotebook
- * container or the GtkVBox object inside the assistant.
+ * container or the GtkBox object inside the assistant.
**/
GtkWidget *